''' Basic configuration module with API's URL and versions. '''

CONFIG = {
    'url': 'api.livechatinc.com',
    'stable': '3.4',
    'dev': '3.5',
}
